# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vald/payload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='vald/payload.proto',
  package='payload',
  syntax='proto3',
  serialized_options=b'\n\026org.vdaas.vald.payloadB\013ValdPayloadP\001Z\'github.com/vdaas/vald/apis/grpc/payload',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12vald/payload.proto\x12\x07payload\x1a\x17validate/validate.proto\"\x9f\x02\n\x06Search\x1aK\n\x07Request\x12\x18\n\x06vector\x18\x01 \x03(\x02\x42\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x12&\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x16.payload.Search.Config\x1a?\n\tIDRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12&\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x16.payload.Search.Config\x1aP\n\x06\x43onfig\x12\x14\n\x03num\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02(\x01\x12\x0e\n\x06radius\x18\x02 \x01(\x02\x12\x0f\n\x07\x65psilon\x18\x03 \x01(\x02\x12\x0f\n\x07timeout\x18\x04 \x01(\x03\x1a\x35\n\x08Response\x12)\n\x07results\x18\x01 \x03(\x0b\x32\x18.payload.Object.Distance\"\xac\x01\n\x04Meta\x1a\x12\n\x03Key\x12\x0b\n\x03key\x18\x01 \x01(\t\x1a\x14\n\x04Keys\x12\x0c\n\x04keys\x18\x01 \x03(\t\x1a\x12\n\x03Val\x12\x0b\n\x03val\x18\x01 \x01(\t\x1a\x14\n\x04Vals\x12\x0c\n\x04vals\x18\x01 \x03(\t\x1a\"\n\x06KeyVal\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0b\n\x03val\x18\x02 \x01(\t\x1a,\n\x07KeyVals\x12!\n\x03kvs\x18\x01 \x03(\x0b\x32\x14.payload.Meta.KeyVal\"\xce\x01\n\x06Object\x1a(\n\x08\x44istance\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x64istance\x18\x02 \x01(\x02\x1a\x19\n\x02ID\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\x12\n\x03IDs\x12\x0b\n\x03ids\x18\x01 \x03(\t\x1a\x37\n\x06Vector\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x06vector\x18\x02 \x03(\x02\x42\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x1a\x32\n\x07Vectors\x12\'\n\x07vectors\x18\x01 \x03(\x0b\x32\x16.payload.Object.Vector\";\n\x07\x43ontrol\x1a\x30\n\x12\x43reateIndexRequest\x12\x1a\n\tpool_size\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02(\x00\"\xc0\x01\n\x0bReplication\x1a\"\n\x08Recovery\x12\x16\n\x0e\x64\x65leted_agents\x18\x01 \x03(\t\x1a@\n\tRebalance\x12\x19\n\x11high_usage_agents\x18\x01 \x03(\t\x12\x18\n\x10low_usage_agents\x18\x02 \x03(\t\x1aK\n\x06\x41gents\x12\x0e\n\x06\x61gents\x18\x01 \x03(\t\x12\x16\n\x0eremoved_agents\x18\x02 \x03(\t\x12\x19\n\x11replicating_agent\x18\x03 \x03(\t\"O\n\nDiscoverer\x1a\x41\n\x07Request\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x0c\n\x04node\x18\x03 \x01(\t\"\xfa\x04\n\x06\x42\x61\x63kup\x1aK\n\tGetVector\x1a \n\x07Request\x12\x15\n\x04uuid\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\x1c\n\x05Owner\x12\x13\n\x02ip\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a-\n\tLocations\x1a \n\x07Request\x12\x15\n\x04uuid\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1aS\n\x06Remove\x1a \n\x07Request\x12\x15\n\x04uuid\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\'\n\x0cRequestMulti\x12\x17\n\x05uuids\x18\x01 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1au\n\x02IP\x1a\x43\n\x08Register\x1a\x37\n\x07Request\x12\x15\n\x04uuid\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x03ips\x18\x02 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a*\n\x06Remove\x1a \n\x07Request\x12\x15\n\x03ips\x18\x01 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1aO\n\nMetaVector\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x0c\n\x04meta\x18\x02 \x01(\t\x12\x18\n\x06vector\x18\x03 \x03(\x02\x42\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x12\x0b\n\x03ips\x18\x04 \x03(\t\x1a:\n\x0bMetaVectors\x12+\n\x07vectors\x18\x01 \x03(\x0b\x32\x1a.payload.Backup.MetaVector\x1a\x9a\x01\n\nCompressed\x1a\x45\n\nMetaVector\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x0c\n\x04meta\x18\x02 \x01(\t\x12\x0e\n\x06vector\x18\x03 \x01(\x0c\x12\x0b\n\x03ips\x18\x04 \x03(\t\x1a\x45\n\x0bMetaVectors\x12\x36\n\x07vectors\x18\x01 \x03(\x0b\x32%.payload.Backup.Compressed.MetaVector\"\xe0\x05\n\x04Info\x1a\x87\x01\n\x05Index\x1a>\n\x05\x43ount\x12\x0e\n\x06stored\x18\x01 \x01(\r\x12\x13\n\x0buncommitted\x18\x02 \x01(\r\x12\x10\n\x08indexing\x18\x03 \x01(\x08\x1a>\n\x04UUID\x1a\x19\n\tCommitted\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x1a\x1b\n\x0bUncommitted\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x1a\xb5\x01\n\x03Pod\x12\x10\n\x08\x61pp_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x13\n\x02ip\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02x\x01\x12\x1e\n\x03\x63pu\x18\x05 \x01(\x0b\x32\x11.payload.Info.CPU\x12$\n\x06memory\x18\x06 \x01(\x0b\x32\x14.payload.Info.Memory\x12 \n\x04node\x18\x07 \x01(\x0b\x32\x12.payload.Info.Node\x1a\xaa\x01\n\x04Node\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rinternal_addr\x18\x02 \x01(\t\x12\x15\n\rexternal_addr\x18\x03 \x01(\t\x12\x1e\n\x03\x63pu\x18\x04 \x01(\x0b\x32\x11.payload.Info.CPU\x12$\n\x06memory\x18\x05 \x01(\x0b\x32\x14.payload.Info.Memory\x12 \n\x04Pods\x18\x06 \x01(\x0b\x32\x12.payload.Info.Pods\x1a\x34\n\x03\x43PU\x12\r\n\x05limit\x18\x01 \x01(\x01\x12\x0f\n\x07request\x18\x02 \x01(\x01\x12\r\n\x05usage\x18\x03 \x01(\x01\x1a\x37\n\x06Memory\x12\r\n\x05limit\x18\x01 \x01(\x01\x12\x0f\n\x07request\x18\x02 \x01(\x01\x12\r\n\x05usage\x18\x03 \x01(\x01\x1a\x31\n\x04Pods\x12)\n\x04pods\x18\x01 \x03(\x0b\x32\x11.payload.Info.PodB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x34\n\x05Nodes\x12+\n\x05nodes\x18\x01 \x03(\x0b\x32\x12.payload.Info.NodeB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x11\n\x03IPs\x12\n\n\x02ip\x18\x01 \x03(\t\"\x07\n\x05\x45mptyBP\n\x16org.vdaas.vald.payloadB\x0bValdPayloadP\x01Z\'github.com/vdaas/vald/apis/grpc/payloadb\x06proto3'
  ,
  dependencies=[validate_dot_validate__pb2.DESCRIPTOR,])




_SEARCH_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.Search.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vector', full_name='payload.Search.Request.vector', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='payload.Search.Request.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=142,
)

_SEARCH_IDREQUEST = _descriptor.Descriptor(
  name='IDRequest',
  full_name='payload.Search.IDRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='payload.Search.IDRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='payload.Search.IDRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=207,
)

_SEARCH_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='payload.Search.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num', full_name='payload.Search.Config.num', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='payload.Search.Config.radius', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epsilon', full_name='payload.Search.Config.epsilon', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='payload.Search.Config.timeout', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=289,
)

_SEARCH_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='payload.Search.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='payload.Search.Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=291,
  serialized_end=344,
)

_SEARCH = _descriptor.Descriptor(
  name='Search',
  full_name='payload.Search',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_SEARCH_REQUEST, _SEARCH_IDREQUEST, _SEARCH_CONFIG, _SEARCH_RESPONSE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=344,
)


_META_KEY = _descriptor.Descriptor(
  name='Key',
  full_name='payload.Meta.Key',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='payload.Meta.Key.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=373,
)

_META_KEYS = _descriptor.Descriptor(
  name='Keys',
  full_name='payload.Meta.Keys',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='payload.Meta.Keys.keys', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=375,
  serialized_end=395,
)

_META_VAL = _descriptor.Descriptor(
  name='Val',
  full_name='payload.Meta.Val',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='payload.Meta.Val.val', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=415,
)

_META_VALS = _descriptor.Descriptor(
  name='Vals',
  full_name='payload.Meta.Vals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vals', full_name='payload.Meta.Vals.vals', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=437,
)

_META_KEYVAL = _descriptor.Descriptor(
  name='KeyVal',
  full_name='payload.Meta.KeyVal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='payload.Meta.KeyVal.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='val', full_name='payload.Meta.KeyVal.val', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=439,
  serialized_end=473,
)

_META_KEYVALS = _descriptor.Descriptor(
  name='KeyVals',
  full_name='payload.Meta.KeyVals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kvs', full_name='payload.Meta.KeyVals.kvs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=475,
  serialized_end=519,
)

_META = _descriptor.Descriptor(
  name='Meta',
  full_name='payload.Meta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_META_KEY, _META_KEYS, _META_VAL, _META_VALS, _META_KEYVAL, _META_KEYVALS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=519,
)


_OBJECT_DISTANCE = _descriptor.Descriptor(
  name='Distance',
  full_name='payload.Object.Distance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='payload.Object.Distance.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance', full_name='payload.Object.Distance.distance', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=572,
)

_OBJECT_ID = _descriptor.Descriptor(
  name='ID',
  full_name='payload.Object.ID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='payload.Object.ID.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=574,
  serialized_end=599,
)

_OBJECT_IDS = _descriptor.Descriptor(
  name='IDs',
  full_name='payload.Object.IDs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='payload.Object.IDs.ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=601,
  serialized_end=619,
)

_OBJECT_VECTOR = _descriptor.Descriptor(
  name='Vector',
  full_name='payload.Object.Vector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='payload.Object.Vector.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector', full_name='payload.Object.Vector.vector', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=621,
  serialized_end=676,
)

_OBJECT_VECTORS = _descriptor.Descriptor(
  name='Vectors',
  full_name='payload.Object.Vectors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vectors', full_name='payload.Object.Vectors.vectors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=678,
  serialized_end=728,
)

_OBJECT = _descriptor.Descriptor(
  name='Object',
  full_name='payload.Object',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_OBJECT_DISTANCE, _OBJECT_ID, _OBJECT_IDS, _OBJECT_VECTOR, _OBJECT_VECTORS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=522,
  serialized_end=728,
)


_CONTROL_CREATEINDEXREQUEST = _descriptor.Descriptor(
  name='CreateIndexRequest',
  full_name='payload.Control.CreateIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pool_size', full_name='payload.Control.CreateIndexRequest.pool_size', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=789,
)

_CONTROL = _descriptor.Descriptor(
  name='Control',
  full_name='payload.Control',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_CONTROL_CREATEINDEXREQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=730,
  serialized_end=789,
)


_REPLICATION_RECOVERY = _descriptor.Descriptor(
  name='Recovery',
  full_name='payload.Replication.Recovery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deleted_agents', full_name='payload.Replication.Recovery.deleted_agents', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=841,
)

_REPLICATION_REBALANCE = _descriptor.Descriptor(
  name='Rebalance',
  full_name='payload.Replication.Rebalance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='high_usage_agents', full_name='payload.Replication.Rebalance.high_usage_agents', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low_usage_agents', full_name='payload.Replication.Rebalance.low_usage_agents', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=843,
  serialized_end=907,
)

_REPLICATION_AGENTS = _descriptor.Descriptor(
  name='Agents',
  full_name='payload.Replication.Agents',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='agents', full_name='payload.Replication.Agents.agents', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='removed_agents', full_name='payload.Replication.Agents.removed_agents', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replicating_agent', full_name='payload.Replication.Agents.replicating_agent', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=909,
  serialized_end=984,
)

_REPLICATION = _descriptor.Descriptor(
  name='Replication',
  full_name='payload.Replication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_REPLICATION_RECOVERY, _REPLICATION_REBALANCE, _REPLICATION_AGENTS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=792,
  serialized_end=984,
)


_DISCOVERER_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.Discoverer.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='payload.Discoverer.Request.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='payload.Discoverer.Request.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node', full_name='payload.Discoverer.Request.node', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1000,
  serialized_end=1065,
)

_DISCOVERER = _descriptor.Descriptor(
  name='Discoverer',
  full_name='payload.Discoverer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_DISCOVERER_REQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=986,
  serialized_end=1065,
)


_BACKUP_GETVECTOR_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.Backup.GetVector.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.Backup.GetVector.Request.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1091,
  serialized_end=1123,
)

_BACKUP_GETVECTOR_OWNER = _descriptor.Descriptor(
  name='Owner',
  full_name='payload.Backup.GetVector.Owner',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='payload.Backup.GetVector.Owner.ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1125,
  serialized_end=1153,
)

_BACKUP_GETVECTOR = _descriptor.Descriptor(
  name='GetVector',
  full_name='payload.Backup.GetVector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_BACKUP_GETVECTOR_REQUEST, _BACKUP_GETVECTOR_OWNER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1078,
  serialized_end=1153,
)

_BACKUP_LOCATIONS_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.Backup.Locations.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.Backup.Locations.Request.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1091,
  serialized_end=1123,
)

_BACKUP_LOCATIONS = _descriptor.Descriptor(
  name='Locations',
  full_name='payload.Backup.Locations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_BACKUP_LOCATIONS_REQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1155,
  serialized_end=1200,
)

_BACKUP_REMOVE_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.Backup.Remove.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.Backup.Remove.Request.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1091,
  serialized_end=1123,
)

_BACKUP_REMOVE_REQUESTMULTI = _descriptor.Descriptor(
  name='RequestMulti',
  full_name='payload.Backup.Remove.RequestMulti',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuids', full_name='payload.Backup.Remove.RequestMulti.uuids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1246,
  serialized_end=1285,
)

_BACKUP_REMOVE = _descriptor.Descriptor(
  name='Remove',
  full_name='payload.Backup.Remove',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_BACKUP_REMOVE_REQUEST, _BACKUP_REMOVE_REQUESTMULTI, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1202,
  serialized_end=1285,
)

_BACKUP_IP_REGISTER_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.Backup.IP.Register.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.Backup.IP.Register.Request.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ips', full_name='payload.Backup.IP.Register.Request.ips', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1305,
  serialized_end=1360,
)

_BACKUP_IP_REGISTER = _descriptor.Descriptor(
  name='Register',
  full_name='payload.Backup.IP.Register',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_BACKUP_IP_REGISTER_REQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1293,
  serialized_end=1360,
)

_BACKUP_IP_REMOVE_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.Backup.IP.Remove.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ips', full_name='payload.Backup.IP.Remove.Request.ips', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1372,
  serialized_end=1404,
)

_BACKUP_IP_REMOVE = _descriptor.Descriptor(
  name='Remove',
  full_name='payload.Backup.IP.Remove',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_BACKUP_IP_REMOVE_REQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1362,
  serialized_end=1404,
)

_BACKUP_IP = _descriptor.Descriptor(
  name='IP',
  full_name='payload.Backup.IP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_BACKUP_IP_REGISTER, _BACKUP_IP_REMOVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1287,
  serialized_end=1404,
)

_BACKUP_METAVECTOR = _descriptor.Descriptor(
  name='MetaVector',
  full_name='payload.Backup.MetaVector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.Backup.MetaVector.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meta', full_name='payload.Backup.MetaVector.meta', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector', full_name='payload.Backup.MetaVector.vector', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ips', full_name='payload.Backup.MetaVector.ips', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1406,
  serialized_end=1485,
)

_BACKUP_METAVECTORS = _descriptor.Descriptor(
  name='MetaVectors',
  full_name='payload.Backup.MetaVectors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vectors', full_name='payload.Backup.MetaVectors.vectors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1487,
  serialized_end=1545,
)

_BACKUP_COMPRESSED_METAVECTOR = _descriptor.Descriptor(
  name='MetaVector',
  full_name='payload.Backup.Compressed.MetaVector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.Backup.Compressed.MetaVector.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meta', full_name='payload.Backup.Compressed.MetaVector.meta', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector', full_name='payload.Backup.Compressed.MetaVector.vector', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ips', full_name='payload.Backup.Compressed.MetaVector.ips', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1562,
  serialized_end=1631,
)

_BACKUP_COMPRESSED_METAVECTORS = _descriptor.Descriptor(
  name='MetaVectors',
  full_name='payload.Backup.Compressed.MetaVectors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vectors', full_name='payload.Backup.Compressed.MetaVectors.vectors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1633,
  serialized_end=1702,
)

_BACKUP_COMPRESSED = _descriptor.Descriptor(
  name='Compressed',
  full_name='payload.Backup.Compressed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_BACKUP_COMPRESSED_METAVECTOR, _BACKUP_COMPRESSED_METAVECTORS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1548,
  serialized_end=1702,
)

_BACKUP = _descriptor.Descriptor(
  name='Backup',
  full_name='payload.Backup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_BACKUP_GETVECTOR, _BACKUP_LOCATIONS, _BACKUP_REMOVE, _BACKUP_IP, _BACKUP_METAVECTOR, _BACKUP_METAVECTORS, _BACKUP_COMPRESSED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1068,
  serialized_end=1702,
)


_INFO_INDEX_COUNT = _descriptor.Descriptor(
  name='Count',
  full_name='payload.Info.Index.Count',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stored', full_name='payload.Info.Index.Count.stored', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uncommitted', full_name='payload.Info.Index.Count.uncommitted', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indexing', full_name='payload.Info.Index.Count.indexing', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1723,
  serialized_end=1785,
)

_INFO_INDEX_UUID_COMMITTED = _descriptor.Descriptor(
  name='Committed',
  full_name='payload.Info.Index.UUID.Committed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.Info.Index.UUID.Committed.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1795,
  serialized_end=1820,
)

_INFO_INDEX_UUID_UNCOMMITTED = _descriptor.Descriptor(
  name='Uncommitted',
  full_name='payload.Info.Index.UUID.Uncommitted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.Info.Index.UUID.Uncommitted.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1822,
  serialized_end=1849,
)

_INFO_INDEX_UUID = _descriptor.Descriptor(
  name='UUID',
  full_name='payload.Info.Index.UUID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_INFO_INDEX_UUID_COMMITTED, _INFO_INDEX_UUID_UNCOMMITTED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1787,
  serialized_end=1849,
)

_INFO_INDEX = _descriptor.Descriptor(
  name='Index',
  full_name='payload.Info.Index',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_INFO_INDEX_COUNT, _INFO_INDEX_UUID, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1714,
  serialized_end=1849,
)

_INFO_POD = _descriptor.Descriptor(
  name='Pod',
  full_name='payload.Info.Pod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_name', full_name='payload.Info.Pod.app_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='payload.Info.Pod.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='payload.Info.Pod.namespace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip', full_name='payload.Info.Pod.ip', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002x\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu', full_name='payload.Info.Pod.cpu', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory', full_name='payload.Info.Pod.memory', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node', full_name='payload.Info.Pod.node', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1852,
  serialized_end=2033,
)

_INFO_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='payload.Info.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='payload.Info.Node.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_addr', full_name='payload.Info.Node.internal_addr', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_addr', full_name='payload.Info.Node.external_addr', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu', full_name='payload.Info.Node.cpu', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory', full_name='payload.Info.Node.memory', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Pods', full_name='payload.Info.Node.Pods', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2036,
  serialized_end=2206,
)

_INFO_CPU = _descriptor.Descriptor(
  name='CPU',
  full_name='payload.Info.CPU',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='limit', full_name='payload.Info.CPU.limit', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request', full_name='payload.Info.CPU.request', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='payload.Info.CPU.usage', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2208,
  serialized_end=2260,
)

_INFO_MEMORY = _descriptor.Descriptor(
  name='Memory',
  full_name='payload.Info.Memory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='limit', full_name='payload.Info.Memory.limit', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request', full_name='payload.Info.Memory.request', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='payload.Info.Memory.usage', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2262,
  serialized_end=2317,
)

_INFO_PODS = _descriptor.Descriptor(
  name='Pods',
  full_name='payload.Info.Pods',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pods', full_name='payload.Info.Pods.pods', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2319,
  serialized_end=2368,
)

_INFO_NODES = _descriptor.Descriptor(
  name='Nodes',
  full_name='payload.Info.Nodes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='payload.Info.Nodes.nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2370,
  serialized_end=2422,
)

_INFO_IPS = _descriptor.Descriptor(
  name='IPs',
  full_name='payload.Info.IPs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='payload.Info.IPs.ip', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2424,
  serialized_end=2441,
)

_INFO = _descriptor.Descriptor(
  name='Info',
  full_name='payload.Info',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_INFO_INDEX, _INFO_POD, _INFO_NODE, _INFO_CPU, _INFO_MEMORY, _INFO_PODS, _INFO_NODES, _INFO_IPS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1705,
  serialized_end=2441,
)


_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='payload.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2443,
  serialized_end=2450,
)

_SEARCH_REQUEST.fields_by_name['config'].message_type = _SEARCH_CONFIG
_SEARCH_REQUEST.containing_type = _SEARCH
_SEARCH_IDREQUEST.fields_by_name['config'].message_type = _SEARCH_CONFIG
_SEARCH_IDREQUEST.containing_type = _SEARCH
_SEARCH_CONFIG.containing_type = _SEARCH
_SEARCH_RESPONSE.fields_by_name['results'].message_type = _OBJECT_DISTANCE
_SEARCH_RESPONSE.containing_type = _SEARCH
_META_KEY.containing_type = _META
_META_KEYS.containing_type = _META
_META_VAL.containing_type = _META
_META_VALS.containing_type = _META
_META_KEYVAL.containing_type = _META
_META_KEYVALS.fields_by_name['kvs'].message_type = _META_KEYVAL
_META_KEYVALS.containing_type = _META
_OBJECT_DISTANCE.containing_type = _OBJECT
_OBJECT_ID.containing_type = _OBJECT
_OBJECT_IDS.containing_type = _OBJECT
_OBJECT_VECTOR.containing_type = _OBJECT
_OBJECT_VECTORS.fields_by_name['vectors'].message_type = _OBJECT_VECTOR
_OBJECT_VECTORS.containing_type = _OBJECT
_CONTROL_CREATEINDEXREQUEST.containing_type = _CONTROL
_REPLICATION_RECOVERY.containing_type = _REPLICATION
_REPLICATION_REBALANCE.containing_type = _REPLICATION
_REPLICATION_AGENTS.containing_type = _REPLICATION
_DISCOVERER_REQUEST.containing_type = _DISCOVERER
_BACKUP_GETVECTOR_REQUEST.containing_type = _BACKUP_GETVECTOR
_BACKUP_GETVECTOR_OWNER.containing_type = _BACKUP_GETVECTOR
_BACKUP_GETVECTOR.containing_type = _BACKUP
_BACKUP_LOCATIONS_REQUEST.containing_type = _BACKUP_LOCATIONS
_BACKUP_LOCATIONS.containing_type = _BACKUP
_BACKUP_REMOVE_REQUEST.containing_type = _BACKUP_REMOVE
_BACKUP_REMOVE_REQUESTMULTI.containing_type = _BACKUP_REMOVE
_BACKUP_REMOVE.containing_type = _BACKUP
_BACKUP_IP_REGISTER_REQUEST.containing_type = _BACKUP_IP_REGISTER
_BACKUP_IP_REGISTER.containing_type = _BACKUP_IP
_BACKUP_IP_REMOVE_REQUEST.containing_type = _BACKUP_IP_REMOVE
_BACKUP_IP_REMOVE.containing_type = _BACKUP_IP
_BACKUP_IP.containing_type = _BACKUP
_BACKUP_METAVECTOR.containing_type = _BACKUP
_BACKUP_METAVECTORS.fields_by_name['vectors'].message_type = _BACKUP_METAVECTOR
_BACKUP_METAVECTORS.containing_type = _BACKUP
_BACKUP_COMPRESSED_METAVECTOR.containing_type = _BACKUP_COMPRESSED
_BACKUP_COMPRESSED_METAVECTORS.fields_by_name['vectors'].message_type = _BACKUP_COMPRESSED_METAVECTOR
_BACKUP_COMPRESSED_METAVECTORS.containing_type = _BACKUP_COMPRESSED
_BACKUP_COMPRESSED.containing_type = _BACKUP
_INFO_INDEX_COUNT.containing_type = _INFO_INDEX
_INFO_INDEX_UUID_COMMITTED.containing_type = _INFO_INDEX_UUID
_INFO_INDEX_UUID_UNCOMMITTED.containing_type = _INFO_INDEX_UUID
_INFO_INDEX_UUID.containing_type = _INFO_INDEX
_INFO_INDEX.containing_type = _INFO
_INFO_POD.fields_by_name['cpu'].message_type = _INFO_CPU
_INFO_POD.fields_by_name['memory'].message_type = _INFO_MEMORY
_INFO_POD.fields_by_name['node'].message_type = _INFO_NODE
_INFO_POD.containing_type = _INFO
_INFO_NODE.fields_by_name['cpu'].message_type = _INFO_CPU
_INFO_NODE.fields_by_name['memory'].message_type = _INFO_MEMORY
_INFO_NODE.fields_by_name['Pods'].message_type = _INFO_PODS
_INFO_NODE.containing_type = _INFO
_INFO_CPU.containing_type = _INFO
_INFO_MEMORY.containing_type = _INFO
_INFO_PODS.fields_by_name['pods'].message_type = _INFO_POD
_INFO_PODS.containing_type = _INFO
_INFO_NODES.fields_by_name['nodes'].message_type = _INFO_NODE
_INFO_NODES.containing_type = _INFO
_INFO_IPS.containing_type = _INFO
DESCRIPTOR.message_types_by_name['Search'] = _SEARCH
DESCRIPTOR.message_types_by_name['Meta'] = _META
DESCRIPTOR.message_types_by_name['Object'] = _OBJECT
DESCRIPTOR.message_types_by_name['Control'] = _CONTROL
DESCRIPTOR.message_types_by_name['Replication'] = _REPLICATION
DESCRIPTOR.message_types_by_name['Discoverer'] = _DISCOVERER
DESCRIPTOR.message_types_by_name['Backup'] = _BACKUP
DESCRIPTOR.message_types_by_name['Info'] = _INFO
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Search = _reflection.GeneratedProtocolMessageType('Search', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_REQUEST,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Search.Request)
    })
  ,

  'IDRequest' : _reflection.GeneratedProtocolMessageType('IDRequest', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_IDREQUEST,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Search.IDRequest)
    })
  ,

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_CONFIG,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Search.Config)
    })
  ,

  'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_RESPONSE,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Search.Response)
    })
  ,
  'DESCRIPTOR' : _SEARCH,
  '__module__' : 'vald.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.Search)
  })
_sym_db.RegisterMessage(Search)
_sym_db.RegisterMessage(Search.Request)
_sym_db.RegisterMessage(Search.IDRequest)
_sym_db.RegisterMessage(Search.Config)
_sym_db.RegisterMessage(Search.Response)

Meta = _reflection.GeneratedProtocolMessageType('Meta', (_message.Message,), {

  'Key' : _reflection.GeneratedProtocolMessageType('Key', (_message.Message,), {
    'DESCRIPTOR' : _META_KEY,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Meta.Key)
    })
  ,

  'Keys' : _reflection.GeneratedProtocolMessageType('Keys', (_message.Message,), {
    'DESCRIPTOR' : _META_KEYS,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Meta.Keys)
    })
  ,

  'Val' : _reflection.GeneratedProtocolMessageType('Val', (_message.Message,), {
    'DESCRIPTOR' : _META_VAL,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Meta.Val)
    })
  ,

  'Vals' : _reflection.GeneratedProtocolMessageType('Vals', (_message.Message,), {
    'DESCRIPTOR' : _META_VALS,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Meta.Vals)
    })
  ,

  'KeyVal' : _reflection.GeneratedProtocolMessageType('KeyVal', (_message.Message,), {
    'DESCRIPTOR' : _META_KEYVAL,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Meta.KeyVal)
    })
  ,

  'KeyVals' : _reflection.GeneratedProtocolMessageType('KeyVals', (_message.Message,), {
    'DESCRIPTOR' : _META_KEYVALS,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Meta.KeyVals)
    })
  ,
  'DESCRIPTOR' : _META,
  '__module__' : 'vald.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.Meta)
  })
_sym_db.RegisterMessage(Meta)
_sym_db.RegisterMessage(Meta.Key)
_sym_db.RegisterMessage(Meta.Keys)
_sym_db.RegisterMessage(Meta.Val)
_sym_db.RegisterMessage(Meta.Vals)
_sym_db.RegisterMessage(Meta.KeyVal)
_sym_db.RegisterMessage(Meta.KeyVals)

Object = _reflection.GeneratedProtocolMessageType('Object', (_message.Message,), {

  'Distance' : _reflection.GeneratedProtocolMessageType('Distance', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_DISTANCE,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Object.Distance)
    })
  ,

  'ID' : _reflection.GeneratedProtocolMessageType('ID', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_ID,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Object.ID)
    })
  ,

  'IDs' : _reflection.GeneratedProtocolMessageType('IDs', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_IDS,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Object.IDs)
    })
  ,

  'Vector' : _reflection.GeneratedProtocolMessageType('Vector', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_VECTOR,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Object.Vector)
    })
  ,

  'Vectors' : _reflection.GeneratedProtocolMessageType('Vectors', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_VECTORS,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Object.Vectors)
    })
  ,
  'DESCRIPTOR' : _OBJECT,
  '__module__' : 'vald.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.Object)
  })
_sym_db.RegisterMessage(Object)
_sym_db.RegisterMessage(Object.Distance)
_sym_db.RegisterMessage(Object.ID)
_sym_db.RegisterMessage(Object.IDs)
_sym_db.RegisterMessage(Object.Vector)
_sym_db.RegisterMessage(Object.Vectors)

Control = _reflection.GeneratedProtocolMessageType('Control', (_message.Message,), {

  'CreateIndexRequest' : _reflection.GeneratedProtocolMessageType('CreateIndexRequest', (_message.Message,), {
    'DESCRIPTOR' : _CONTROL_CREATEINDEXREQUEST,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Control.CreateIndexRequest)
    })
  ,
  'DESCRIPTOR' : _CONTROL,
  '__module__' : 'vald.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.Control)
  })
_sym_db.RegisterMessage(Control)
_sym_db.RegisterMessage(Control.CreateIndexRequest)

Replication = _reflection.GeneratedProtocolMessageType('Replication', (_message.Message,), {

  'Recovery' : _reflection.GeneratedProtocolMessageType('Recovery', (_message.Message,), {
    'DESCRIPTOR' : _REPLICATION_RECOVERY,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Replication.Recovery)
    })
  ,

  'Rebalance' : _reflection.GeneratedProtocolMessageType('Rebalance', (_message.Message,), {
    'DESCRIPTOR' : _REPLICATION_REBALANCE,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Replication.Rebalance)
    })
  ,

  'Agents' : _reflection.GeneratedProtocolMessageType('Agents', (_message.Message,), {
    'DESCRIPTOR' : _REPLICATION_AGENTS,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Replication.Agents)
    })
  ,
  'DESCRIPTOR' : _REPLICATION,
  '__module__' : 'vald.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.Replication)
  })
_sym_db.RegisterMessage(Replication)
_sym_db.RegisterMessage(Replication.Recovery)
_sym_db.RegisterMessage(Replication.Rebalance)
_sym_db.RegisterMessage(Replication.Agents)

Discoverer = _reflection.GeneratedProtocolMessageType('Discoverer', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _DISCOVERER_REQUEST,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Discoverer.Request)
    })
  ,
  'DESCRIPTOR' : _DISCOVERER,
  '__module__' : 'vald.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.Discoverer)
  })
_sym_db.RegisterMessage(Discoverer)
_sym_db.RegisterMessage(Discoverer.Request)

Backup = _reflection.GeneratedProtocolMessageType('Backup', (_message.Message,), {

  'GetVector' : _reflection.GeneratedProtocolMessageType('GetVector', (_message.Message,), {

    'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
      'DESCRIPTOR' : _BACKUP_GETVECTOR_REQUEST,
      '__module__' : 'vald.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.Backup.GetVector.Request)
      })
    ,

    'Owner' : _reflection.GeneratedProtocolMessageType('Owner', (_message.Message,), {
      'DESCRIPTOR' : _BACKUP_GETVECTOR_OWNER,
      '__module__' : 'vald.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.Backup.GetVector.Owner)
      })
    ,
    'DESCRIPTOR' : _BACKUP_GETVECTOR,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Backup.GetVector)
    })
  ,

  'Locations' : _reflection.GeneratedProtocolMessageType('Locations', (_message.Message,), {

    'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
      'DESCRIPTOR' : _BACKUP_LOCATIONS_REQUEST,
      '__module__' : 'vald.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.Backup.Locations.Request)
      })
    ,
    'DESCRIPTOR' : _BACKUP_LOCATIONS,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Backup.Locations)
    })
  ,

  'Remove' : _reflection.GeneratedProtocolMessageType('Remove', (_message.Message,), {

    'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
      'DESCRIPTOR' : _BACKUP_REMOVE_REQUEST,
      '__module__' : 'vald.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.Backup.Remove.Request)
      })
    ,

    'RequestMulti' : _reflection.GeneratedProtocolMessageType('RequestMulti', (_message.Message,), {
      'DESCRIPTOR' : _BACKUP_REMOVE_REQUESTMULTI,
      '__module__' : 'vald.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.Backup.Remove.RequestMulti)
      })
    ,
    'DESCRIPTOR' : _BACKUP_REMOVE,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Backup.Remove)
    })
  ,

  'IP' : _reflection.GeneratedProtocolMessageType('IP', (_message.Message,), {

    'Register' : _reflection.GeneratedProtocolMessageType('Register', (_message.Message,), {

      'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
        'DESCRIPTOR' : _BACKUP_IP_REGISTER_REQUEST,
        '__module__' : 'vald.payload_pb2'
        # @@protoc_insertion_point(class_scope:payload.Backup.IP.Register.Request)
        })
      ,
      'DESCRIPTOR' : _BACKUP_IP_REGISTER,
      '__module__' : 'vald.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.Backup.IP.Register)
      })
    ,

    'Remove' : _reflection.GeneratedProtocolMessageType('Remove', (_message.Message,), {

      'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
        'DESCRIPTOR' : _BACKUP_IP_REMOVE_REQUEST,
        '__module__' : 'vald.payload_pb2'
        # @@protoc_insertion_point(class_scope:payload.Backup.IP.Remove.Request)
        })
      ,
      'DESCRIPTOR' : _BACKUP_IP_REMOVE,
      '__module__' : 'vald.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.Backup.IP.Remove)
      })
    ,
    'DESCRIPTOR' : _BACKUP_IP,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Backup.IP)
    })
  ,

  'MetaVector' : _reflection.GeneratedProtocolMessageType('MetaVector', (_message.Message,), {
    'DESCRIPTOR' : _BACKUP_METAVECTOR,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Backup.MetaVector)
    })
  ,

  'MetaVectors' : _reflection.GeneratedProtocolMessageType('MetaVectors', (_message.Message,), {
    'DESCRIPTOR' : _BACKUP_METAVECTORS,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Backup.MetaVectors)
    })
  ,

  'Compressed' : _reflection.GeneratedProtocolMessageType('Compressed', (_message.Message,), {

    'MetaVector' : _reflection.GeneratedProtocolMessageType('MetaVector', (_message.Message,), {
      'DESCRIPTOR' : _BACKUP_COMPRESSED_METAVECTOR,
      '__module__' : 'vald.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.Backup.Compressed.MetaVector)
      })
    ,

    'MetaVectors' : _reflection.GeneratedProtocolMessageType('MetaVectors', (_message.Message,), {
      'DESCRIPTOR' : _BACKUP_COMPRESSED_METAVECTORS,
      '__module__' : 'vald.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.Backup.Compressed.MetaVectors)
      })
    ,
    'DESCRIPTOR' : _BACKUP_COMPRESSED,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Backup.Compressed)
    })
  ,
  'DESCRIPTOR' : _BACKUP,
  '__module__' : 'vald.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.Backup)
  })
_sym_db.RegisterMessage(Backup)
_sym_db.RegisterMessage(Backup.GetVector)
_sym_db.RegisterMessage(Backup.GetVector.Request)
_sym_db.RegisterMessage(Backup.GetVector.Owner)
_sym_db.RegisterMessage(Backup.Locations)
_sym_db.RegisterMessage(Backup.Locations.Request)
_sym_db.RegisterMessage(Backup.Remove)
_sym_db.RegisterMessage(Backup.Remove.Request)
_sym_db.RegisterMessage(Backup.Remove.RequestMulti)
_sym_db.RegisterMessage(Backup.IP)
_sym_db.RegisterMessage(Backup.IP.Register)
_sym_db.RegisterMessage(Backup.IP.Register.Request)
_sym_db.RegisterMessage(Backup.IP.Remove)
_sym_db.RegisterMessage(Backup.IP.Remove.Request)
_sym_db.RegisterMessage(Backup.MetaVector)
_sym_db.RegisterMessage(Backup.MetaVectors)
_sym_db.RegisterMessage(Backup.Compressed)
_sym_db.RegisterMessage(Backup.Compressed.MetaVector)
_sym_db.RegisterMessage(Backup.Compressed.MetaVectors)

Info = _reflection.GeneratedProtocolMessageType('Info', (_message.Message,), {

  'Index' : _reflection.GeneratedProtocolMessageType('Index', (_message.Message,), {

    'Count' : _reflection.GeneratedProtocolMessageType('Count', (_message.Message,), {
      'DESCRIPTOR' : _INFO_INDEX_COUNT,
      '__module__' : 'vald.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.Info.Index.Count)
      })
    ,

    'UUID' : _reflection.GeneratedProtocolMessageType('UUID', (_message.Message,), {

      'Committed' : _reflection.GeneratedProtocolMessageType('Committed', (_message.Message,), {
        'DESCRIPTOR' : _INFO_INDEX_UUID_COMMITTED,
        '__module__' : 'vald.payload_pb2'
        # @@protoc_insertion_point(class_scope:payload.Info.Index.UUID.Committed)
        })
      ,

      'Uncommitted' : _reflection.GeneratedProtocolMessageType('Uncommitted', (_message.Message,), {
        'DESCRIPTOR' : _INFO_INDEX_UUID_UNCOMMITTED,
        '__module__' : 'vald.payload_pb2'
        # @@protoc_insertion_point(class_scope:payload.Info.Index.UUID.Uncommitted)
        })
      ,
      'DESCRIPTOR' : _INFO_INDEX_UUID,
      '__module__' : 'vald.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.Info.Index.UUID)
      })
    ,
    'DESCRIPTOR' : _INFO_INDEX,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Info.Index)
    })
  ,

  'Pod' : _reflection.GeneratedProtocolMessageType('Pod', (_message.Message,), {
    'DESCRIPTOR' : _INFO_POD,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Info.Pod)
    })
  ,

  'Node' : _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
    'DESCRIPTOR' : _INFO_NODE,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Info.Node)
    })
  ,

  'CPU' : _reflection.GeneratedProtocolMessageType('CPU', (_message.Message,), {
    'DESCRIPTOR' : _INFO_CPU,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Info.CPU)
    })
  ,

  'Memory' : _reflection.GeneratedProtocolMessageType('Memory', (_message.Message,), {
    'DESCRIPTOR' : _INFO_MEMORY,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Info.Memory)
    })
  ,

  'Pods' : _reflection.GeneratedProtocolMessageType('Pods', (_message.Message,), {
    'DESCRIPTOR' : _INFO_PODS,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Info.Pods)
    })
  ,

  'Nodes' : _reflection.GeneratedProtocolMessageType('Nodes', (_message.Message,), {
    'DESCRIPTOR' : _INFO_NODES,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Info.Nodes)
    })
  ,

  'IPs' : _reflection.GeneratedProtocolMessageType('IPs', (_message.Message,), {
    'DESCRIPTOR' : _INFO_IPS,
    '__module__' : 'vald.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.Info.IPs)
    })
  ,
  'DESCRIPTOR' : _INFO,
  '__module__' : 'vald.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.Info)
  })
_sym_db.RegisterMessage(Info)
_sym_db.RegisterMessage(Info.Index)
_sym_db.RegisterMessage(Info.Index.Count)
_sym_db.RegisterMessage(Info.Index.UUID)
_sym_db.RegisterMessage(Info.Index.UUID.Committed)
_sym_db.RegisterMessage(Info.Index.UUID.Uncommitted)
_sym_db.RegisterMessage(Info.Pod)
_sym_db.RegisterMessage(Info.Node)
_sym_db.RegisterMessage(Info.CPU)
_sym_db.RegisterMessage(Info.Memory)
_sym_db.RegisterMessage(Info.Pods)
_sym_db.RegisterMessage(Info.Nodes)
_sym_db.RegisterMessage(Info.IPs)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'vald.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.Empty)
  })
_sym_db.RegisterMessage(Empty)


DESCRIPTOR._options = None
_SEARCH_REQUEST.fields_by_name['vector']._options = None
_SEARCH_CONFIG.fields_by_name['num']._options = None
_OBJECT_ID.fields_by_name['id']._options = None
_OBJECT_VECTOR.fields_by_name['id']._options = None
_OBJECT_VECTOR.fields_by_name['vector']._options = None
_CONTROL_CREATEINDEXREQUEST.fields_by_name['pool_size']._options = None
_DISCOVERER_REQUEST.fields_by_name['name']._options = None
_BACKUP_GETVECTOR_REQUEST.fields_by_name['uuid']._options = None
_BACKUP_GETVECTOR_OWNER.fields_by_name['ip']._options = None
_BACKUP_LOCATIONS_REQUEST.fields_by_name['uuid']._options = None
_BACKUP_REMOVE_REQUEST.fields_by_name['uuid']._options = None
_BACKUP_REMOVE_REQUESTMULTI.fields_by_name['uuids']._options = None
_BACKUP_IP_REGISTER_REQUEST.fields_by_name['uuid']._options = None
_BACKUP_IP_REGISTER_REQUEST.fields_by_name['ips']._options = None
_BACKUP_IP_REMOVE_REQUEST.fields_by_name['ips']._options = None
_BACKUP_METAVECTOR.fields_by_name['vector']._options = None
_INFO_POD.fields_by_name['ip']._options = None
_INFO_PODS.fields_by_name['pods']._options = None
_INFO_NODES.fields_by_name['nodes']._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from vald import payload_pb2 as vald_dot_payload__pb2


class ValdStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Exists = channel.unary_unary(
                '/vald.Vald/Exists',
                request_serializer=vald_dot_payload__pb2.Object.ID.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Object.ID.FromString,
                )
        self.Search = channel.unary_unary(
                '/vald.Vald/Search',
                request_serializer=vald_dot_payload__pb2.Search.Request.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Search.Response.FromString,
                )
        self.SearchByID = channel.unary_unary(
                '/vald.Vald/SearchByID',
                request_serializer=vald_dot_payload__pb2.Search.IDRequest.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Search.Response.FromString,
                )
        self.StreamSearch = channel.stream_stream(
                '/vald.Vald/StreamSearch',
                request_serializer=vald_dot_payload__pb2.Search.Request.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Search.Response.FromString,
                )
        self.StreamSearchByID = channel.stream_stream(
                '/vald.Vald/StreamSearchByID',
                request_serializer=vald_dot_payload__pb2.Search.IDRequest.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Search.Response.FromString,
                )
        self.Insert = channel.unary_unary(
                '/vald.Vald/Insert',
                request_serializer=vald_dot_payload__pb2.Object.Vector.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Empty.FromString,
                )
        self.StreamInsert = channel.stream_stream(
                '/vald.Vald/StreamInsert',
                request_serializer=vald_dot_payload__pb2.Object.Vector.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Empty.FromString,
                )
        self.MultiInsert = channel.unary_unary(
                '/vald.Vald/MultiInsert',
                request_serializer=vald_dot_payload__pb2.Object.Vectors.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Empty.FromString,
                )
        self.Update = channel.unary_unary(
                '/vald.Vald/Update',
                request_serializer=vald_dot_payload__pb2.Object.Vector.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Empty.FromString,
                )
        self.StreamUpdate = channel.stream_stream(
                '/vald.Vald/StreamUpdate',
                request_serializer=vald_dot_payload__pb2.Object.Vector.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Empty.FromString,
                )
        self.MultiUpdate = channel.unary_unary(
                '/vald.Vald/MultiUpdate',
                request_serializer=vald_dot_payload__pb2.Object.Vectors.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Empty.FromString,
                )
        self.Upsert = channel.unary_unary(
                '/vald.Vald/Upsert',
                request_serializer=vald_dot_payload__pb2.Object.Vector.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Empty.FromString,
                )
        self.StreamUpsert = channel.stream_stream(
                '/vald.Vald/StreamUpsert',
                request_serializer=vald_dot_payload__pb2.Object.Vector.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Empty.FromString,
                )
        self.MultiUpsert = channel.unary_unary(
                '/vald.Vald/MultiUpsert',
                request_serializer=vald_dot_payload__pb2.Object.Vectors.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Empty.FromString,
                )
        self.Remove = channel.unary_unary(
                '/vald.Vald/Remove',
                request_serializer=vald_dot_payload__pb2.Object.ID.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Empty.FromString,
                )
        self.StreamRemove = channel.stream_stream(
                '/vald.Vald/StreamRemove',
                request_serializer=vald_dot_payload__pb2.Object.ID.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Empty.FromString,
                )
        self.MultiRemove = channel.unary_unary(
                '/vald.Vald/MultiRemove',
                request_serializer=vald_dot_payload__pb2.Object.IDs.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Empty.FromString,
                )
        self.GetObject = channel.unary_unary(
                '/vald.Vald/GetObject',
                request_serializer=vald_dot_payload__pb2.Object.ID.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Backup.MetaVector.FromString,
                )
        self.StreamGetObject = channel.stream_stream(
                '/vald.Vald/StreamGetObject',
                request_serializer=vald_dot_payload__pb2.Object.ID.SerializeToString,
                response_deserializer=vald_dot_payload__pb2.Backup.MetaVector.FromString,
                )


class ValdServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Exists(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Search(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchByID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamSearch(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamSearchByID(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Insert(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamInsert(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MultiInsert(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamUpdate(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MultiUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Upsert(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamUpsert(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MultiUpsert(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Remove(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamRemove(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MultiRemove(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamGetObject(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ValdServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Exists': grpc.unary_unary_rpc_method_handler(
                    servicer.Exists,
                    request_deserializer=vald_dot_payload__pb2.Object.ID.FromString,
                    response_serializer=vald_dot_payload__pb2.Object.ID.SerializeToString,
            ),
            'Search': grpc.unary_unary_rpc_method_handler(
                    servicer.Search,
                    request_deserializer=vald_dot_payload__pb2.Search.Request.FromString,
                    response_serializer=vald_dot_payload__pb2.Search.Response.SerializeToString,
            ),
            'SearchByID': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchByID,
                    request_deserializer=vald_dot_payload__pb2.Search.IDRequest.FromString,
                    response_serializer=vald_dot_payload__pb2.Search.Response.SerializeToString,
            ),
            'StreamSearch': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamSearch,
                    request_deserializer=vald_dot_payload__pb2.Search.Request.FromString,
                    response_serializer=vald_dot_payload__pb2.Search.Response.SerializeToString,
            ),
            'StreamSearchByID': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamSearchByID,
                    request_deserializer=vald_dot_payload__pb2.Search.IDRequest.FromString,
                    response_serializer=vald_dot_payload__pb2.Search.Response.SerializeToString,
            ),
            'Insert': grpc.unary_unary_rpc_method_handler(
                    servicer.Insert,
                    request_deserializer=vald_dot_payload__pb2.Object.Vector.FromString,
                    response_serializer=vald_dot_payload__pb2.Empty.SerializeToString,
            ),
            'StreamInsert': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamInsert,
                    request_deserializer=vald_dot_payload__pb2.Object.Vector.FromString,
                    response_serializer=vald_dot_payload__pb2.Empty.SerializeToString,
            ),
            'MultiInsert': grpc.unary_unary_rpc_method_handler(
                    servicer.MultiInsert,
                    request_deserializer=vald_dot_payload__pb2.Object.Vectors.FromString,
                    response_serializer=vald_dot_payload__pb2.Empty.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=vald_dot_payload__pb2.Object.Vector.FromString,
                    response_serializer=vald_dot_payload__pb2.Empty.SerializeToString,
            ),
            'StreamUpdate': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamUpdate,
                    request_deserializer=vald_dot_payload__pb2.Object.Vector.FromString,
                    response_serializer=vald_dot_payload__pb2.Empty.SerializeToString,
            ),
            'MultiUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.MultiUpdate,
                    request_deserializer=vald_dot_payload__pb2.Object.Vectors.FromString,
                    response_serializer=vald_dot_payload__pb2.Empty.SerializeToString,
            ),
            'Upsert': grpc.unary_unary_rpc_method_handler(
                    servicer.Upsert,
                    request_deserializer=vald_dot_payload__pb2.Object.Vector.FromString,
                    response_serializer=vald_dot_payload__pb2.Empty.SerializeToString,
            ),
            'StreamUpsert': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamUpsert,
                    request_deserializer=vald_dot_payload__pb2.Object.Vector.FromString,
                    response_serializer=vald_dot_payload__pb2.Empty.SerializeToString,
            ),
            'MultiUpsert': grpc.unary_unary_rpc_method_handler(
                    servicer.MultiUpsert,
                    request_deserializer=vald_dot_payload__pb2.Object.Vectors.FromString,
                    response_serializer=vald_dot_payload__pb2.Empty.SerializeToString,
            ),
            'Remove': grpc.unary_unary_rpc_method_handler(
                    servicer.Remove,
                    request_deserializer=vald_dot_payload__pb2.Object.ID.FromString,
                    response_serializer=vald_dot_payload__pb2.Empty.SerializeToString,
            ),
            'StreamRemove': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamRemove,
                    request_deserializer=vald_dot_payload__pb2.Object.ID.FromString,
                    response_serializer=vald_dot_payload__pb2.Empty.SerializeToString,
            ),
            'MultiRemove': grpc.unary_unary_rpc_method_handler(
                    servicer.MultiRemove,
                    request_deserializer=vald_dot_payload__pb2.Object.IDs.FromString,
                    response_serializer=vald_dot_payload__pb2.Empty.SerializeToString,
            ),
            'GetObject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObject,
                    request_deserializer=vald_dot_payload__pb2.Object.ID.FromString,
                    response_serializer=vald_dot_payload__pb2.Backup.MetaVector.SerializeToString,
            ),
            'StreamGetObject': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamGetObject,
                    request_deserializer=vald_dot_payload__pb2.Object.ID.FromString,
                    response_serializer=vald_dot_payload__pb2.Backup.MetaVector.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'vald.Vald', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Vald(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Exists(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.Vald/Exists',
            vald_dot_payload__pb2.Object.ID.SerializeToString,
            vald_dot_payload__pb2.Object.ID.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Search(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.Vald/Search',
            vald_dot_payload__pb2.Search.Request.SerializeToString,
            vald_dot_payload__pb2.Search.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchByID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.Vald/SearchByID',
            vald_dot_payload__pb2.Search.IDRequest.SerializeToString,
            vald_dot_payload__pb2.Search.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamSearch(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/vald.Vald/StreamSearch',
            vald_dot_payload__pb2.Search.Request.SerializeToString,
            vald_dot_payload__pb2.Search.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamSearchByID(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/vald.Vald/StreamSearchByID',
            vald_dot_payload__pb2.Search.IDRequest.SerializeToString,
            vald_dot_payload__pb2.Search.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Insert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.Vald/Insert',
            vald_dot_payload__pb2.Object.Vector.SerializeToString,
            vald_dot_payload__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamInsert(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/vald.Vald/StreamInsert',
            vald_dot_payload__pb2.Object.Vector.SerializeToString,
            vald_dot_payload__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MultiInsert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.Vald/MultiInsert',
            vald_dot_payload__pb2.Object.Vectors.SerializeToString,
            vald_dot_payload__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.Vald/Update',
            vald_dot_payload__pb2.Object.Vector.SerializeToString,
            vald_dot_payload__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamUpdate(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/vald.Vald/StreamUpdate',
            vald_dot_payload__pb2.Object.Vector.SerializeToString,
            vald_dot_payload__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MultiUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.Vald/MultiUpdate',
            vald_dot_payload__pb2.Object.Vectors.SerializeToString,
            vald_dot_payload__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Upsert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.Vald/Upsert',
            vald_dot_payload__pb2.Object.Vector.SerializeToString,
            vald_dot_payload__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamUpsert(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/vald.Vald/StreamUpsert',
            vald_dot_payload__pb2.Object.Vector.SerializeToString,
            vald_dot_payload__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MultiUpsert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.Vald/MultiUpsert',
            vald_dot_payload__pb2.Object.Vectors.SerializeToString,
            vald_dot_payload__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Remove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.Vald/Remove',
            vald_dot_payload__pb2.Object.ID.SerializeToString,
            vald_dot_payload__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamRemove(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/vald.Vald/StreamRemove',
            vald_dot_payload__pb2.Object.ID.SerializeToString,
            vald_dot_payload__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MultiRemove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.Vald/MultiRemove',
            vald_dot_payload__pb2.Object.IDs.SerializeToString,
            vald_dot_payload__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vald.Vald/GetObject',
            vald_dot_payload__pb2.Object.ID.SerializeToString,
            vald_dot_payload__pb2.Backup.MetaVector.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamGetObject(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/vald.Vald/StreamGetObject',
            vald_dot_payload__pb2.Object.ID.SerializeToString,
            vald_dot_payload__pb2.Backup.MetaVector.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vald/vald.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vald import payload_pb2 as vald_dot_payload__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='vald/vald.proto',
  package='vald',
  syntax='proto3',
  serialized_options=b'\n\033org.vdaas.vald.gateway.valdB\007ValdApiP\001Z,github.com/vdaas/vald/apis/grpc/gateway/vald',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0fvald/vald.proto\x12\x04vald\x1a\x12vald/payload.proto\x1a\x1cgoogle/api/annotations.proto2\x9b\n\n\x04Vald\x12\x46\n\x06\x45xists\x12\x12.payload.Object.ID\x1a\x12.payload.Object.ID\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/exists/{id}\x12O\n\x06Search\x12\x17.payload.Search.Request\x1a\x18.payload.Search.Response\"\x12\x82\xd3\xe4\x93\x02\x0c\"\x07/search:\x01*\x12X\n\nSearchByID\x12\x19.payload.Search.IDRequest\x1a\x18.payload.Search.Response\"\x15\x82\xd3\xe4\x93\x02\x0f\"\n/search/id:\x01*\x12G\n\x0cStreamSearch\x12\x17.payload.Search.Request\x1a\x18.payload.Search.Response\"\x00(\x01\x30\x01\x12M\n\x10StreamSearchByID\x12\x19.payload.Search.IDRequest\x1a\x18.payload.Search.Response\"\x00(\x01\x30\x01\x12\x44\n\x06Insert\x12\x16.payload.Object.Vector\x1a\x0e.payload.Empty\"\x12\x82\xd3\xe4\x93\x02\x0c\"\x07/insert:\x01*\x12<\n\x0cStreamInsert\x12\x16.payload.Object.Vector\x1a\x0e.payload.Empty\"\x00(\x01\x30\x01\x12\x38\n\x0bMultiInsert\x12\x17.payload.Object.Vectors\x1a\x0e.payload.Empty\"\x00\x12\x44\n\x06Update\x12\x16.payload.Object.Vector\x1a\x0e.payload.Empty\"\x12\x82\xd3\xe4\x93\x02\x0c\"\x07/update:\x01*\x12<\n\x0cStreamUpdate\x12\x16.payload.Object.Vector\x1a\x0e.payload.Empty\"\x00(\x01\x30\x01\x12\x38\n\x0bMultiUpdate\x12\x17.payload.Object.Vectors\x1a\x0e.payload.Empty\"\x00\x12\x44\n\x06Upsert\x12\x16.payload.Object.Vector\x1a\x0e.payload.Empty\"\x12\x82\xd3\xe4\x93\x02\x0c\"\x07/upsert:\x01*\x12<\n\x0cStreamUpsert\x12\x16.payload.Object.Vector\x1a\x0e.payload.Empty\"\x00(\x01\x30\x01\x12\x38\n\x0bMultiUpsert\x12\x17.payload.Object.Vectors\x1a\x0e.payload.Empty\"\x00\x12\x42\n\x06Remove\x12\x12.payload.Object.ID\x1a\x0e.payload.Empty\"\x14\x82\xd3\xe4\x93\x02\x0e*\x0c/remove/{id}\x12\x38\n\x0cStreamRemove\x12\x12.payload.Object.ID\x1a\x0e.payload.Empty\"\x00(\x01\x30\x01\x12\x34\n\x0bMultiRemove\x12\x13.payload.Object.IDs\x1a\x0e.payload.Empty\"\x00\x12Q\n\tGetObject\x12\x12.payload.Object.ID\x1a\x1a.payload.Backup.MetaVector\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/object/{id}\x12G\n\x0fStreamGetObject\x12\x12.payload.Object.ID\x1a\x1a.payload.Backup.MetaVector\"\x00(\x01\x30\x01\x42V\n\x1borg.vdaas.vald.gateway.valdB\x07ValdApiP\x01Z,github.com/vdaas/vald/apis/grpc/gateway/valdb\x06proto3'
  ,
  dependencies=[vald_dot_payload__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_VALD = _descriptor.ServiceDescriptor(
  name='Vald',
  full_name='vald.Vald',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=76,
  serialized_end=1383,
  methods=[
  _descriptor.MethodDescriptor(
    name='Exists',
    full_name='vald.Vald.Exists',
    index=0,
    containing_service=None,
    input_type=vald_dot_payload__pb2._OBJECT_ID,
    output_type=vald_dot_payload__pb2._OBJECT_ID,
    serialized_options=b'\202\323\344\223\002\016\022\014/exists/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Search',
    full_name='vald.Vald.Search',
    index=1,
    containing_service=None,
    input_type=vald_dot_payload__pb2._SEARCH_REQUEST,
    output_type=vald_dot_payload__pb2._SEARCH_RESPONSE,
    serialized_options=b'\202\323\344\223\002\014\"\007/search:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SearchByID',
    full_name='vald.Vald.SearchByID',
    index=2,
    containing_service=None,
    input_type=vald_dot_payload__pb2._SEARCH_IDREQUEST,
    output_type=vald_dot_payload__pb2._SEARCH_RESPONSE,
    serialized_options=b'\202\323\344\223\002\017\"\n/search/id:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamSearch',
    full_name='vald.Vald.StreamSearch',
    index=3,
    containing_service=None,
    input_type=vald_dot_payload__pb2._SEARCH_REQUEST,
    output_type=vald_dot_payload__pb2._SEARCH_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamSearchByID',
    full_name='vald.Vald.StreamSearchByID',
    index=4,
    containing_service=None,
    input_type=vald_dot_payload__pb2._SEARCH_IDREQUEST,
    output_type=vald_dot_payload__pb2._SEARCH_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Insert',
    full_name='vald.Vald.Insert',
    index=5,
    containing_service=None,
    input_type=vald_dot_payload__pb2._OBJECT_VECTOR,
    output_type=vald_dot_payload__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\014\"\007/insert:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamInsert',
    full_name='vald.Vald.StreamInsert',
    index=6,
    containing_service=None,
    input_type=vald_dot_payload__pb2._OBJECT_VECTOR,
    output_type=vald_dot_payload__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MultiInsert',
    full_name='vald.Vald.MultiInsert',
    index=7,
    containing_service=None,
    input_type=vald_dot_payload__pb2._OBJECT_VECTORS,
    output_type=vald_dot_payload__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='vald.Vald.Update',
    index=8,
    containing_service=None,
    input_type=vald_dot_payload__pb2._OBJECT_VECTOR,
    output_type=vald_dot_payload__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\014\"\007/update:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamUpdate',
    full_name='vald.Vald.StreamUpdate',
    index=9,
    containing_service=None,
    input_type=vald_dot_payload__pb2._OBJECT_VECTOR,
    output_type=vald_dot_payload__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MultiUpdate',
    full_name='vald.Vald.MultiUpdate',
    index=10,
    containing_service=None,
    input_type=vald_dot_payload__pb2._OBJECT_VECTORS,
    output_type=vald_dot_payload__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Upsert',
    full_name='vald.Vald.Upsert',
    index=11,
    containing_service=None,
    input_type=vald_dot_payload__pb2._OBJECT_VECTOR,
    output_type=vald_dot_payload__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\014\"\007/upsert:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamUpsert',
    full_name='vald.Vald.StreamUpsert',
    index=12,
    containing_service=None,
    input_type=vald_dot_payload__pb2._OBJECT_VECTOR,
    output_type=vald_dot_payload__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MultiUpsert',
    full_name='vald.Vald.MultiUpsert',
    index=13,
    containing_service=None,
    input_type=vald_dot_payload__pb2._OBJECT_VECTORS,
    output_type=vald_dot_payload__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Remove',
    full_name='vald.Vald.Remove',
    index=14,
    containing_service=None,
    input_type=vald_dot_payload__pb2._OBJECT_ID,
    output_type=vald_dot_payload__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\016*\014/remove/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamRemove',
    full_name='vald.Vald.StreamRemove',
    index=15,
    containing_service=None,
    input_type=vald_dot_payload__pb2._OBJECT_ID,
    output_type=vald_dot_payload__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MultiRemove',
    full_name='vald.Vald.MultiRemove',
    index=16,
    containing_service=None,
    input_type=vald_dot_payload__pb2._OBJECT_IDS,
    output_type=vald_dot_payload__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetObject',
    full_name='vald.Vald.GetObject',
    index=17,
    containing_service=None,
    input_type=vald_dot_payload__pb2._OBJECT_ID,
    output_type=vald_dot_payload__pb2._BACKUP_METAVECTOR,
    serialized_options=b'\202\323\344\223\002\016\022\014/object/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamGetObject',
    full_name='vald.Vald.StreamGetObject',
    index=18,
    containing_service=None,
    input_type=vald_dot_payload__pb2._OBJECT_ID,
    output_type=vald_dot_payload__pb2._BACKUP_METAVECTOR,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VALD)

DESCRIPTOR.services_by_name['Vald'] = _VALD

# @@protoc_insertion_point(module_scope)
